
'-- Sample script for use with jsHTTP2.IPInfo object in jsHTTP2.exe. To use this script,
'   register jsHTTP2.exe. For location info. you will also need to obtain and register the
'   MaxMind DLL and have a copy of the MaxMind database. (See the help for full explanation.)
'     There are some settings options below that should be checked before running the script.
'    If you are sure that the script is ready for your use, just drop a server log raw file
'    onto it. The script will generate a new file with "C" added to the file name. (C for Converted.)
'    The new file will have IP addresses replaced with host names and, optionally, location
'    info. for the IP address.

'    The way this script works is to parse out the client IP address from each line, convert
'   then all to host names, where possible, then write a new log with that new data. Since
'   the call to get the host name must call a remote server and then may have to wait for
'   a response, the method to get a host name, GetHostNameFromIP, is a sub that's called
'   and then the response comes in the event OnHostNameResult. jsHTTP2.IPInfo has a
'   boolean property Busy that is designed to allow a script to keep running while it waits for
'   the remote server response. 


Dim FSO, TS, IP
Dim ALines, AIPs(), AHosts(), sLog, sFol, sFil, sFilName, sTitle, s2, s1, sRec, DBPath, sHost
Dim Pt1, i2, iDex, UB1, Ret, VisitorCount, iTimeOut
Dim BooGeo, Boo1


 'On Error Resume Next
 sTitle = "Convert IP to Hostname"

'------------------------- Settings -------------------------------

'-- (1)    set database path:
DBPath = "D:\GeoLiteCity\GeoIPCity.dat"    '-- EDIT HERE. DBPath must be valid.

'-- (2)    set timeout in ms for GetHostNameFromIP. Default is 5 seconds (5000). Maximum is 60 seconds (60000).
  '--   iTimeOut = 5000    '-- This probably does not need to be changed.

'-- (3)    Also see lines 87+- to 98+- for needed adjustments there. Typical Unix logs have a syntax like so:
'--           40.40.40.40. -- [28/Jan/2009:00:01:49 -0800] "GET /jsware/linzips/disp.zip HTTP/1.1" 200 ... etc.

'              Each line in the log represents a GET request to the server and each line starts with the client
'              IP address, followed by 2 dashes as separator. This script, therefore, works by looking for "-"
'              in each line, clipping off the IP, then adding back the IP/Location info. or HostName/Location info.
'              later, when writing the new log file, so that 40.40.40.40 -- becomes something like:
'              www.somewhere.com*Toledo-OH-US --
'              If your log has a different separator character, or if the client IP is not the first thing in each line,
'              the parsing code will have to be changed. You will need some knowledge of VBScript for that.

'------------------------------------------------------------------

sLog = WScript.Arguments(0)

Set FSO = CreateObject("Scripting.FileSystemObject")
    If FSO.FileExists(sLog) = False Then
       MsgBox "Drop a server log file onto script for processing.", 64, sTitle
       Set FSO = Nothing
       WScript.Quit
    End If   
  
'-- get log file path and add "C" to file name for new file.
Pt1 = InStrRev(sLog, "\") 
sFol = Left(sLog, Pt1)
sFilName = Right(sLog, (len(sLog) - Pt1))
 Pt1 = InStrRev(sFilName, ".")
  If Pt1 > 0 Then 
     sFil = sFol & Left(sFilName, (Pt1 - 1)) & "C.txt"
  Else
     sFil = sLog & "C.txt"
  End If
  
  '-- open the log file and read it out. ----------
 
 Set TS = FSO.OpenTextFile(sLog, 1)
   s2 = TS.ReadAll
   TS.Close
 Set TS = Nothing

ALines = Split(s2, vbLf)
UB1 = UBound(ALines)

ReDim AIPs(UB1)
ReDim AHosts(UB1)

For i2 = 0 to UB1
     s1 = ALines(i2)
        If Len(s1) > 2 Then  '-- drop blank lines.
                    
               '-- EDIT HERE. ADJUSTMENT FOR LOG FILE SYNTAX  ------------------------------   
                   '-- this is where customizing may be needed for differing log formats.
                   '-- As written, this code picks out IP addresses that are at beginning of line, followed by "-" - typical Unix log format.
                   '-- If you have a site on a Windows server it may require more work to parse the lines
                   '-- because the visitor IP address will probably be in the middle of the line.
               Pt1 = InStr(1, s1, "-")
                 If Pt1 > 0 Then
                    s2 = Left(s1, (Pt1 - 1))
                    s2 = Trim(s2)
                    ALines(i2) = Right(s1, (len(s1) - (Pt1 - 2)))      '-- string is like: 40.40.40.40 - - etc. Separate the IP from the space, dash, and so on.
                    AIPs(i2) = s2
                 End If   
        End If   
     
Next     

  '-- create the IPInfo object. ------------------------  
Set IP = WScript.CreateObject("jsHTTP2.IPInfo", "IP_")
 
' -- set timeout:
  IP.TimeOut = iTimeOut
  
  '-- This must be called to initialize winsock so that remote servers can be queried for IP -> Host name data.
  '-- GetLocationFromIPcannot be called until this is called with a successful return of 0.
Ret = IP.EnableHostNameData() 
  If (Ret <> 0) Then
    MsgBox "Failed to initialize Winsock. Error: " & CStr(Ret), 64, smsg
    Set IP = Nothing
    WScript.Quit
  End If   
  
  '-- This must be called before trying to get location info. It loads the GeoIPEx.dll library and 
  '-- tells it the path of the GeoCityLite database file. Without this the script will still run but
  '-- location info. will not be included. There is no need for the script to deal directly with GeoIPEx.dll.
  '-- It is loaded and set to nothing inside of the IPInfo object. EnableLocationData is just
  '-- provided as an orderly way to load the DLL and find the database path, to make sure that
  '  location data is accessible before trying to retrieve it.
  
'-- Note: IPInfo tries to avoid possible errors here by checking for the database path, but
'-- The GeoIpComEx.dll function in is fautly. If you look at the MaxMind docs you'll see that set_db_path
'-- is used to inform the DLL of the database path. It's supposed to return a boolean value. 
'-- But it always returns False, and MaxMind's own sample code shows it used as a sub.

Ret = IP.EnableLocationData(DBPath)
  Select Case Ret
    Case 0
       BooGeo = True  '-- enable location data.
    Case Else
     '-- problem here will usually be either that the DLL is not registered or DBPath is not a valid path to the MaxMind database.
      MsgBox "Location Info. error " & Ret & ": " & IP.ErrorString, 64, sTitle   
  End Select     
  
iDex = -1

 Do
    iDex = iDex + 1
      If iDex > UB1 Then Exit Do
       '-- loop through host names array until one is found that hasn't been filled in.
       '-- Since a typical visitor will send numerous GETs, each time an IP is translated
       '-- that translation is applied to all lines with the same IP. So, for instance,
       '-- if line 20 was just translated and lines 21-28 have the same originating IP
       '-- then the script will have filled in the corresponding array elements in AHosts.
       '-- So the next IP to process is the one on the next line that's different.
                  
       sHost = AHosts(iDex)
    If Len(sHost) = 0 Then  
        DoNextIP
    End If  
 Loop   

       WScript.DisconnectObject IP  '-- this should be called to disconnect events before setting to nothing.
       Set IP = Nothing
       WriteFile
       WScript.quit
    
' ------------------- end of script ----------------
'------------------- subs below here ------------------------

  '-- call for the next IP translation and then go into a wait loop.
Sub DoNextIP()
   Dim sIP1
     sIP1 = AIPs(iDex)
     If (Len(sIP1) > 0) Then
        IP.GetHostNameFromIP sIP1
          While IP.Busy = True
          Wend
     End If   
End Sub

  '   IPInfo.Busy is set internally to False when this event is fired, so the script will
  '  automatically "wake up" from its wait loop at the right time.
  '-- when event fires, check for host name. If no host name was found then use IP as host name.
  '-- either way, put that value into all indices of AHosts where AIPs(index) matches the IP
  '-- number.
Sub IP_OnHostNameResult(vIP, vHost, ErrorCode)
 Dim i3, sHost, Loc, sLoc, sCntry

  If (BooGeo = True) Then 
    Set Loc = IP.GetLocationFromIP(vIP)
      If Loc.Valid = True Then
          sCntry = Loc.Country
       '-- This part is optional. It just reduces "United States"  to "US" and "United Kingdom" to "UK" in order
       '-- to save space in the finished version of the log, for the sake of easier reading.
        If (sCntry = "United States") Then
            sCntry = "US"
        ElseIf (sCntry = "United Kingdom") Then
            sCntry = "UK"
        End If     
         sLoc = Chr(149) & Loc.City & "-" & Loc.Region & "-" & sCntry
      End If
    Set Loc = Nothing   
  End If
     '-- for any index in IP array that matches this current IP, fill in the corresponding host array index. 
  For i3 = 0 to UB1
    If AIPs(i3) = vIP Then
       If (Len(vHost) > 0) Then
           AHosts(i3) = vHost & sLoc
       Else
           AHosts(i3) = vIP & sLoc
       End If  
    End If
  Next   
    VisitorCount = VisitorCount + 1
End Sub

Sub WriteFile()
  Dim s3, i4
    For i4 = 0 to UB1
      s3 = AHosts(i4) & ALines(i4)
      ALines(i4) = s3
   Next
     s3 = Join(ALines, vbLf)
     s3 = "Visitor count: " & CStr(VisitorCount) & vbCrLf & vbCrLf & s3
     Set TS = FSO.CreateTextFile(sFil, True)
       TS.Write s3
       TS.Close    
     Set TS = Nothing  
     Set FSO = Nothing
     MsgBox "Done."
     WScript.quit 
End Sub

 